@@ -1,5 +1,12 @@
-NNshapeReg <- function(x,y,n,mahalanobis=FALSE,mc.cores = detectCores())
+NNshapeReg <- function(x,y=NULL, n=3, mahalanobis=FALSE,mc.cores = detectCores())
   {
+      if (is.null(y))
+          y <- x
+      outdim <- dim(y)
+      if (length(dim(x)) == 3)
+          x <- vecx(x)
+      if (length(dim(y)) == 3)
+          y <- vecx(y)
     i <- NULL
     win <- FALSE
      if(.Platform$OS.type == "windows")
@@ -18,6 +25,15 @@ NNshapeReg <- function(x,y,n,mahalanobis=FALSE,mc.cores = detectCores())
       out <- foreach(i=1:dim(x)[1],.combine=rbind) %do% estfun(i)
     else
       out <- foreach(i=1:dim(x)[1],.combine=rbind) %dopar% estfun(i)
+
+      if (length(outdim) == 3)
+          {
+              out1 <- array(NA, dim=outdim)
+              for (i in 1:outdim[3])
+                  out1[,,i] <- matrix(out[i,],outdim[1],outdim[2])
+                   
+              out <- out1
+          }
     return(out)
   }
 
