@@ -7,15 +7,13 @@ mcNNindex <- function(target,query,cores=detectCores(),k=k,...)
         out <- NULL
         mclist <- list()
         nx <- dim(query)[1]
-        iter <-floor(nx/cores)
-        if (cores > 1)
-            {
-                for (i in 1:(cores-1))
-                    mclist[[i]] <- query[(1:iter)+((i-1)*iter),]
-                
-                mclist[[cores]] <-  query[-c(1:((cores-1)*iter)),]
-            }
-        else
+        iter <- floor(nx/cores)
+        if (cores > 1) {
+            for (i in 1:(cores-1))
+                mclist[[i]] <- query[(1:iter)+((i-1)*iter),]
+            
+            mclist[[cores]] <- query[-c(1:((cores-1)*iter)),]
+        }  else
             mclist[[1]] <- query
         tmpfun <- function(x,...)
             {
@@ -24,9 +22,11 @@ mcNNindex <- function(target,query,cores=detectCores(),k=k,...)
                 return(tmp0)
             }
         tmp <- mclapply(mclist,tmpfun,mc.cores=cores)
-        for (i in 1:cores)
-            out <- rbind(out,tmp[[i]])
-            
+        if (k > 1) {
+            for (i in 1:cores)
+                out <- rbind(out,tmp[[i]])
+        } else {
+            out <- unlist(tmp)
+        }
         return(out)
-
     }
