@@ -85,7 +85,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getInputStream(int)
 	 */
-	public InputStream getInputStream(int index)
+	public synchronized InputStream getInputStream(int index)
 	{
 		return (InputStream)get(index);
 	}
@@ -98,7 +98,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setInputStream(int, java.io.InputStream)
 	 */
-	public void setInputStream(int index, InputStream element)
+	public synchronized void setInputStream(int index, InputStream element)
 	{
 		set(index, element);
 	}
@@ -111,7 +111,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addInputStream(int, java.io.InputStream)
 	 */
-	public void addInputStream(int index, InputStream element)
+	public synchronized void addInputStream(int index, InputStream element)
 	{
 		add(index, element);
 	}
@@ -124,7 +124,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addInputStream(java.io.InputStream)
 	 */
-	public boolean addInputStream(InputStream element)
+	public synchronized boolean addInputStream(InputStream element)
 	{
 		return add(element);
 	}
@@ -137,7 +137,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getBigDecimal(int)
 	 */
-	public BigDecimal getBigDecimal(int index)
+	public synchronized BigDecimal getBigDecimal(int index)
 	{
 		Object obj = get(index);
 
@@ -166,7 +166,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setBigDecimal(int, java.math.BigDecimal)
 	 */
-	public void setBigDecimal(int index, BigDecimal element)
+	public synchronized void setBigDecimal(int index, BigDecimal element)
 	{
 		set(index, element);
 	}
@@ -179,7 +179,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addBigDecimal(int, java.math.BigDecimal)
 	 */
-	public void addBigDecimal(int index, BigDecimal element)
+	public synchronized void addBigDecimal(int index, BigDecimal element)
 	{
 		add(index, element);
 	}
@@ -192,7 +192,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addBigDecimal(java.math.BigDecimal)
 	 */
-	public boolean addBigDecimal(BigDecimal element)
+	public synchronized boolean addBigDecimal(BigDecimal element)
 	{
 		return add(element);
 	}
@@ -205,7 +205,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getBigInteger(int)
 	 */
-	public BigInteger getBigInteger(int index)
+	public synchronized BigInteger getBigInteger(int index)
 	{
 		Object obj = get(index);
 
@@ -234,7 +234,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setBigInteger(int, java.math.BigInteger)
 	 */
-	public void setBigInteger(int index, BigInteger element)
+	public synchronized void setBigInteger(int index, BigInteger element)
 	{
 		set(index, element);
 	}
@@ -247,7 +247,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addBigInteger(int, java.math.BigInteger)
 	 */
-	public void addBigInteger(int index, BigInteger element)
+	public synchronized void addBigInteger(int index, BigInteger element)
 	{
 		add(index, element);
 	}
@@ -260,7 +260,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addBigInteger(java.math.BigInteger)
 	 */
-	public boolean addBigInteger(BigInteger element)
+	public synchronized boolean addBigInteger(BigInteger element)
 	{
 		return add(element);
 	}
@@ -273,7 +273,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getBoolean(int)
 	 */
-	public boolean getBoolean(int index)
+	public synchronized boolean getBoolean(int index)
 	{
 		Object obj = get(index);
 
@@ -300,7 +300,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setBoolean(int, boolean)
 	 */
-	public void setBoolean(int index, boolean element)
+	public synchronized void setBoolean(int index, boolean element)
 	{
 		set(index, new Boolean(element));
 	}
@@ -313,7 +313,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addBoolean(int, boolean)
 	 */
-	public void addBoolean(int index, boolean element)
+	public synchronized void addBoolean(int index, boolean element)
 	{
 		add(index, new Boolean(element));
 	}
@@ -326,7 +326,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addBoolean(boolean)
 	 */
-	public boolean addBoolean(boolean element)
+	public synchronized boolean addBoolean(boolean element)
 	{
 		return add(new Boolean(element));
 	}
@@ -339,7 +339,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getByte(int)
 	 */
-	public byte getByte(int index)
+	public synchronized byte getByte(int index)
 	{
 		Object obj = get(index);
 
@@ -368,7 +368,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setByte(int, byte)
 	 */
-	public void setByte(int index, byte element)
+	public synchronized void setByte(int index, byte element)
 	{
 		set(index, new Byte(element));
 	}
@@ -381,7 +381,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addByte(int, byte)
 	 */
-	public void addByte(int index, byte element)
+	public synchronized void addByte(int index, byte element)
 	{
 		add(index, new Byte(element));
 	}
@@ -394,7 +394,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addByte(byte)
 	 */
-	public boolean addByte(byte element)
+	public synchronized boolean addByte(byte element)
 	{
 		return add(new Byte(element));
 	}
@@ -407,7 +407,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getBytes(int)
 	 */
-	public byte[] getBytes(int index)
+	public synchronized byte[] getBytes(int index)
 	{
 		return (byte[])get(index);
 	}
@@ -420,7 +420,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setBytes(int, byte[])
 	 */
-	public void setBytes(int index, byte[] element)
+	public synchronized void setBytes(int index, byte[] element)
 	{
 		set(index, element);
 	}
@@ -433,7 +433,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addBytes(int, byte[])
 	 */
-	public void addBytes(int index, byte[] element)
+	public synchronized void addBytes(int index, byte[] element)
 	{
 		add(index, element);
 	}
@@ -446,7 +446,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addBytes(byte[])
 	 */
-	public boolean addBytes(byte[] element)
+	public synchronized boolean addBytes(byte[] element)
 	{
 		return add(element);
 	}
@@ -459,7 +459,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getChar(int)
 	 */
-	public char getChar(int index)
+	public synchronized char getChar(int index)
 	{
 		Object obj = get(index);
 
@@ -488,7 +488,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setChar(int, char)
 	 */
-	public void setChar(int index, char element)
+	public synchronized void setChar(int index, char element)
 	{
 		set(index, new Character(element));
 	}
@@ -501,7 +501,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addChar(int, char)
 	 */
-	public void addChar(int index, char element)
+	public synchronized void addChar(int index, char element)
 	{
 		add(index, new Character(element));
 	}
@@ -514,7 +514,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addChar(char)
 	 */
-	public boolean addChar(char element)
+	public synchronized boolean addChar(char element)
 	{
 		return add(new Character(element));
 	}
@@ -527,7 +527,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getReader(int)
 	 */
-	public Reader getReader(int index)
+	public synchronized Reader getReader(int index)
 	{
 		return (Reader)get(index);
 	}
@@ -540,7 +540,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setReader(int, java.io.Reader)
 	 */
-	public void setReader(int index, Reader element)
+	public synchronized void setReader(int index, Reader element)
 	{
 		set(index, element);
 	}
@@ -553,7 +553,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addReader(int, java.io.Reader)
 	 */
-	public void addReader(int index, Reader element)
+	public synchronized void addReader(int index, Reader element)
 	{
 		add(index, element);
 	}
@@ -566,7 +566,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addReader(java.io.Reader)
 	 */
-	public boolean addReader(Reader element)
+	public synchronized boolean addReader(Reader element)
 	{
 		return add(element);
 	}
@@ -579,7 +579,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getDate(int)
 	 */
-	public Date getDate(int index)
+	public synchronized Date getDate(int index)
 	{
 		Object obj = get(index);
 
@@ -688,7 +688,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#parseDate(int, java.lang.String)
 	 */
-	public Date parseDate(int index, String pattern)
+	public synchronized Date parseDate(int index, String pattern)
 	{
 		Object obj = get(index);
 
@@ -716,7 +716,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setDate(int, java.util.Date)
 	 */
-	public void setDate(int index, Date element)
+	public synchronized void setDate(int index, Date element)
 	{
 		set(index, element);
 	}
@@ -729,7 +729,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addDate(int, java.util.Date)
 	 */
-	public void addDate(int index, Date element)
+	public synchronized void addDate(int index, Date element)
 	{
 		add(index, element);
 	}
@@ -742,7 +742,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addDate(java.util.Date)
 	 */
-	public boolean addDate(Date element)
+	public synchronized boolean addDate(Date element)
 	{
 		return add(element);
 	}
@@ -755,7 +755,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getDouble(int)
 	 */
-	public double getDouble(int index)
+	public synchronized double getDouble(int index)
 	{
 		Object obj = get(index);
 
@@ -784,7 +784,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setDouble(int, double)
 	 */
-	public void setDouble(int index, double element)
+	public synchronized void setDouble(int index, double element)
 	{
 		set(index, new Double(element));
 	}
@@ -797,7 +797,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addDouble(int, double)
 	 */
-	public void addDouble(int index, double element)
+	public synchronized void addDouble(int index, double element)
 	{
 		add(index, new Double(element));
 	}
@@ -810,7 +810,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addDouble(double)
 	 */
-	public boolean addDouble(double element)
+	public synchronized boolean addDouble(double element)
 	{
 		return add(new Double(element));
 	}
@@ -823,7 +823,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getFloat(int)
 	 */
-	public float getFloat(int index)
+	public synchronized float getFloat(int index)
 	{
 		Object obj = get(index);
 
@@ -852,7 +852,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setFloat(int, float)
 	 */
-	public void setFloat(int index, float element)
+	public synchronized void setFloat(int index, float element)
 	{
 		set(index, new Float(element));
 	}
@@ -865,7 +865,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addFloat(int, float)
 	 */
-	public void addFloat(int index, float element)
+	public synchronized void addFloat(int index, float element)
 	{
 		add(index, new Float(element));
 	}
@@ -878,7 +878,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addFloat(float)
 	 */
-	public boolean addFloat(float element)
+	public synchronized boolean addFloat(float element)
 	{
 		return add(new Float(element));
 	}
@@ -891,7 +891,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getInt(int)
 	 */
-	public int getInt(int index)
+	public synchronized int getInt(int index)
 	{
 		Object obj = get(index);
 
@@ -920,7 +920,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setInt(int, int)
 	 */
-	public void setInt(int index, int element)
+	public synchronized void setInt(int index, int element)
 	{
 		set(index, new Integer(element));
 	}
@@ -933,7 +933,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addInt(int, int)
 	 */
-	public void addInt(int index, int element)
+	public synchronized void addInt(int index, int element)
 	{
 		add(index, new Integer(element));
 	}
@@ -946,7 +946,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addInt(int)
 	 */
-	public boolean addInt(int element)
+	public synchronized boolean addInt(int element)
 	{
 		return add(new Integer(element));
 	}
@@ -959,7 +959,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getLong(int)
 	 */
-	public long getLong(int index)
+	public synchronized long getLong(int index)
 	{
 		Object obj = get(index);
 
@@ -988,7 +988,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setLong(int, long)
 	 */
-	public void setLong(int index, long element)
+	public synchronized void setLong(int index, long element)
 	{
 		set(index, new Long(element));
 	}
@@ -1001,7 +1001,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addLong(int, long)
 	 */
-	public void addLong(int index, long element)
+	public synchronized void addLong(int index, long element)
 	{
 		add(index, new Long(element));
 	}
@@ -1014,7 +1014,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addLong(long)
 	 */
-	public boolean addLong(long element)
+	public synchronized boolean addLong(long element)
 	{
 		return add(new Long(element));
 	}
@@ -1027,7 +1027,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getObject(int)
 	 */
-	public Object getObject(int index)
+	public synchronized Object getObject(int index)
 	{
 		return get(index);
 	}
@@ -1040,7 +1040,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setObject(int, java.lang.Object)
 	 */
-	public void setObject(int index, Object element)
+	public synchronized void setObject(int index, Object element)
 	{
 		set(index, element);
 	}
@@ -1053,7 +1053,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addObject(int, java.lang.Object)
 	 */
-	public void addObject(int index, Object element)
+	public synchronized void addObject(int index, Object element)
 	{
 		add(index, element);
 	}
@@ -1066,7 +1066,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addObject(java.lang.Object)
 	 */
-	public boolean addObject(Object element)
+	public synchronized boolean addObject(Object element)
 	{
 		return add(element);
 	}
@@ -1079,7 +1079,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getShort(int)
 	 */
-	public short getShort(int index)
+	public synchronized short getShort(int index)
 	{
 		Object obj = get(index);
 
@@ -1108,7 +1108,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setShort(int, short)
 	 */
-	public void setShort(int index, short element)
+	public synchronized void setShort(int index, short element)
 	{
 		set(index, new Short(element));
 	}
@@ -1121,7 +1121,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addShort(int, short)
 	 */
-	public void addShort(int index, short element)
+	public synchronized void addShort(int index, short element)
 	{
 		add(index, new Short(element));
 	}
@@ -1134,7 +1134,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addShort(short)
 	 */
-	public boolean addShort(short element)
+	public synchronized boolean addShort(short element)
 	{
 		return add(new Short(element));
 	}
@@ -1147,7 +1147,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getString(int)
 	 */
-	public String getString(int index)
+	public synchronized String getString(int index)
 	{
 		Object obj = get(index);
 
@@ -1174,7 +1174,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setString(int, java.lang.String)
 	 */
-	public void setString(int index, String element)
+	public synchronized void setString(int index, String element)
 	{
 		set(index, element);
 	}
@@ -1187,7 +1187,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addString(int, java.lang.String)
 	 */
-	public void addString(int index, String element)
+	public synchronized void addString(int index, String element)
 	{
 		add(index, element);
 	}
@@ -1200,7 +1200,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addString(java.lang.String)
 	 */
-	public boolean addString(String element)
+	public synchronized boolean addString(String element)
 	{
 		return add(element);
 	}
@@ -1213,7 +1213,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getList(int)
 	 */
-	public List getList(int index)
+	public synchronized List getList(int index)
 	{
 		return (List)get(index);
 	}
@@ -1226,7 +1226,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setList(int, java.util.List)
 	 */
-	public void setList(int index, List element)
+	public synchronized void setList(int index, List element)
 	{
 		set(index, element);
 	}
@@ -1239,7 +1239,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addList(int, java.util.List)
 	 */
-	public void addList(int index, List element)
+	public synchronized void addList(int index, List element)
 	{
 		add(index, element);
 	}
@@ -1252,7 +1252,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addList(java.util.List)
 	 */
-	public boolean addList(List element)
+	public synchronized boolean addList(List element)
 	{
 		return add(element);
 	}
@@ -1265,7 +1265,7 @@ public class ConversionList
 	 * @return Xg̎w肳ꂽʒuɂvf
 	 * @see jp.morpho.util.PrimitiveHolderList#getMap(int)
 	 */
-	public Map getMap(int index)
+	public synchronized Map getMap(int index)
 	{
 		return (Map)get(index);
 	}
@@ -1278,7 +1278,7 @@ public class ConversionList
 	 * @param element w肳ꂽʒuɊi[vf
 	 * @see jp.morpho.util.PrimitiveHolderList#setMap(int, java.util.Map)
 	 */
-	public void setMap(int index, Map element)
+	public synchronized void setMap(int index, Map element)
 	{
 		set(index, element);
 	}
@@ -1291,7 +1291,7 @@ public class ConversionList
 	 * @param element }vf
 	 * @see jp.morpho.util.PrimitiveHolderList#addMap(int, java.util.Map)
 	 */
-	public void addMap(int index, Map element)
+	public synchronized void addMap(int index, Map element)
 	{
 		add(index, element);
 	}
@@ -1304,7 +1304,7 @@ public class ConversionList
 	 * @return ̌ĂяǒʁAXgύXꂽꍇ true
 	 * @see jp.morpho.util.PrimitiveHolderList#addMap(java.util.Map)
 	 */
-	public boolean addMap(Map element)
+	public synchronized boolean addMap(Map element)
 	{
 		return add(element);
 	}
