@@ -44,7 +44,7 @@ import jp.morpho.webapp.resource.MessageResourceManager;
 
 /**
  * <P>
- * `FbN{bNXAWI{^Aj[Ȃǂ̃Rg[^Onh`邽߂̊NXłB
+ * ^Onh`邽߂̊NXłB
  * </P>
  * @author Kumiko Hiroi
  */
@@ -165,7 +165,6 @@ public abstract class BaseTag
 	/**
 	 * <P>
 	 * ^O{̂]ɁAĕ]s킸ɁAy[W𑱍s܂B
-	 * ftHgł́AbodyContent ̃f[^ (݂ꍇ) ͑삵܂B
 	 * </P>
 	 * @return SKIP_BODY
 	 * @see javax.servlet.jsp.tagext.IterationTag#doAfterBody()
@@ -184,7 +183,7 @@ public abstract class BaseTag
 				throw new JspException(e.getMessage());
 			}
 		}
-		return super.doAfterBody();
+		return SKIP_BODY;
 	}
 
 	/**
