@@ -42,9 +42,18 @@ import jp.morpho.webapp.action.ActionMappingManager;
  * @author Kumiko Hiroi
  */
 public class ActionButtonTag
-	extends InputTag
+	extends ButtonTag
 {
 
+	/** action  */
+	private String action = null;
+
+	/** form  */
+	private String form = null;
+
+	/** status  */
+	private String status = null;
+
 	/**
 	 * <P>
 	 * ActionButtonTag 쐬܂B
@@ -63,7 +72,7 @@ public class ActionButtonTag
 	 */
 	public String getAction()
 	{
-		return this.getAttributeMap().getString("action");
+		return (action != null) ? action : "";
 	}
 
 	/**
@@ -74,7 +83,7 @@ public class ActionButtonTag
 	 */
 	public String getForm()
 	{
-		return this.getAttributeMap().getString("form");
+		return (form != null) ? form : "";
 	}
 
 	/**
@@ -85,7 +94,7 @@ public class ActionButtonTag
 	 */
 	public String getStatus()
 	{
-		return this.getAttributeMap().getString("status");
+		return (status != null) ? status : "";
 	}
 
 	/**
@@ -96,7 +105,7 @@ public class ActionButtonTag
 	 */
 	public void setAction(String action)
 	{
-		this.getAttributeMap().putString("action", action);
+		this.action = action;
 	}
 
 	/**
@@ -107,7 +116,7 @@ public class ActionButtonTag
 	 */
 	public void setForm(String form)
 	{
-		this.getAttributeMap().putString("form", form);
+		this.form = form;
 	}
 
 	/**
@@ -118,7 +127,7 @@ public class ActionButtonTag
 	 */
 	public void setStatus(String status)
 	{
-		this.getAttributeMap().putString("status", status);
+		this.status = status;
 	}
 
 	/**
@@ -142,14 +151,12 @@ public class ActionButtonTag
 	 */
 	public int doStartTag() throws JspException
 	{
-		this.setType("button");
-
 		ActionMappingManager amm = getActionMappingManager();
 		StringBuffer buf = new StringBuffer();
 		String formName = null;
-		if (this.getAttributeMap().containsKey("form"))
+		if (this.form != null)
 		{
-			formName = this.getForm();
+			formName = this.form;
 		}
 		else
 		{
@@ -169,24 +176,29 @@ public class ActionButtonTag
 
 		//action
 		buf.append(formName).append(".").append(amm.getActionParameterName())
-			.append(".value='").append(this.getAction()).append("';");
+			.append(".value='").append(this.action).append("';");
 
 		//status
 		if (this.getAttributeMap().containsKey("status"))
 		{
 			buf.append("document.").append(formName).append(".").append(amm.getStatusParameterName())
-				.append(".value='").append(this.getStatus()).append("';");
+				.append(".value='").append(this.status).append("';");
 		}
 
 		buf.append(formName).append(".submit();");
 
+		String onclick = this.getOnclick();
+		if (onclick == null || onclick.trim().equals(""))
+		{
+			buf.insert(0, "javascript:");
+		}
+		else
+		{
+			buf.insert(0, ";");
+			buf.insert(0, onclick);
+		}
 		this.setOnclick(buf.toString());
 
-		this.getAttributeMap().remove("action");
-		this.getAttributeMap().remove("status");
-		this.getAttributeMap().remove("form");
-		this.setValueByMessageResource();
-
 		return super.doStartTag();
 	}
 
