@@ -29,15 +29,18 @@
 package jp.morpho.webapp.servlet.jsp.tagext.html;
 
 import java.io.IOException;
+import java.util.Map;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.JspWriter;
+import javax.servlet.jsp.tagext.Tag;
 
 import jp.morpho.util.ConversionMap;
 import jp.morpho.webapp.servlet.http.HttpActionRequest;
 import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;
 import jp.morpho.webapp.servlet.jsp.tagext.BaseTag;
+import jp.morpho.webapp.servlet.jsp.tagext.ListTag;
 
 /**
  * <P>
@@ -94,10 +97,7 @@ public class EncodeTag
 
 		if (this.getAttributeMap().containsKey("name"))
 		{
-			HttpActionRequest request =
-				HttpActionRequestFactory.getInstance().getRequest(
-					(HttpServletRequest)pageContext.getRequest());
-			ConversionMap param = ConversionMap.valueOf(request.getParameterMap());
+			ConversionMap param = ConversionMap.valueOf(this.getParameterMap());
 			HtmlEncoder encoder = this.getTagManager().getHtmlEncoder();
 			if (!param.getString(this.getName()).equals(""))
 			{
@@ -118,4 +118,41 @@ public class EncodeTag
 		return super.doStartTag();
 	}
 
+	/**
+	 * <P>
+	 * p[^̃}bvԂ܂B
+	 * </P>
+	 * @return p[^̃}bv
+	 */
+	protected Map getParameterMap()
+	{
+		Map map = null;
+
+		ListTag listTag = null;
+		for (Tag tag = this.getParent();
+				tag != null;
+					tag = tag.getParent())
+		{
+			if (tag instanceof ListTag)
+			{
+				listTag = (ListTag)tag;
+				break;
+			}
+		}
+
+		if (listTag == null)
+		{
+			HttpActionRequest request =
+				HttpActionRequestFactory.getInstance().getRequest(
+					(HttpServletRequest)pageContext.getRequest());
+			map = request.getParameterMap();
+		}
+		else
+		{
+			map = listTag.getRowMap();
+		}
+
+		return map;
+	}
+
 }
