@@ -67,7 +67,7 @@ import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;
  * </P>
  * @author Kumiko Hiroi
  */
-public class FormTag extends ControlTagSupport
+public class FormTag extends AttrsSupportTag
 {
 
 	/**
@@ -97,7 +97,7 @@ public class FormTag extends ControlTagSupport
 	 * </P>
 	 * @return accept-charset 
 	 */
-	public String getAcceptCharset()
+	public String getAcceptcharset()
 	{
 		return getAttributeMap().getString("accept-charset");
 	}
@@ -185,7 +185,7 @@ public class FormTag extends ControlTagSupport
 	 * </P>
 	 * @param acceptCharset accept-charset 
 	 */
-	public void setAcceptCharset(String acceptCharset)
+	public void setAcceptcharset(String acceptCharset)
 	{
 		getAttributeMap().putString("accept-charset", acceptCharset);
 	}
