@@ -37,8 +37,6 @@ import javax.servlet.jsp.JspWriter;
 
 import jp.morpho.util.ConversionMap;
 import jp.morpho.webapp.resource.MessageResourceManager;
-import jp.morpho.webapp.servlet.http.HttpActionRequest;
-import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;
 import jp.morpho.webapp.servlet.http.HttpSessionAttributeNames;
 import jp.morpho.webapp.servlet.jsp.tagext.TagManager;
 import jp.morpho.webapp.servlet.jsp.tagext.TagTemplate;
@@ -629,10 +627,7 @@ public abstract class InputTag
 	{
 		if (!this.getAttributeMap().containsKey("checked") && this.getAttributeMap().containsKey("name"))
 		{
-			HttpActionRequest request =
-				HttpActionRequestFactory.getInstance().getRequest(
-					(HttpServletRequest)pageContext.getRequest());
-			ConversionMap param = ConversionMap.valueOf(request.getParameterMap());
+			ConversionMap param = ConversionMap.valueOf(this.getParameterMap());
 			if (!param.isNull(this.getName()))
 			{
 				if (param.isArray(this.getName()))
@@ -669,10 +664,7 @@ public abstract class InputTag
 	{
 		if (!this.getAttributeMap().containsKey("value") && this.getAttributeMap().containsKey("name"))
 		{
-			HttpActionRequest request =
-				HttpActionRequestFactory.getInstance().getRequest(
-					(HttpServletRequest)pageContext.getRequest());
-			ConversionMap param = ConversionMap.valueOf(request.getParameterMap());
+			ConversionMap param = ConversionMap.valueOf(this.getParameterMap());
 			HtmlEncoder encoder = this.getTagManager().getHtmlEncoder();
 			if (param.containsKey(this.getName()))
 			{
