@@ -30,14 +30,11 @@ package jp.morpho.webapp.servlet.jsp.tagext.html;
 
 import java.io.IOException;
 
-import javax.servlet.http.HttpServletRequest;
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.JspWriter;
 import javax.servlet.jsp.tagext.Tag;
 
 import jp.morpho.util.ConversionMap;
-import jp.morpho.webapp.servlet.http.HttpActionRequest;
-import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;
 
 /**
  * <P>
@@ -208,10 +205,7 @@ public class OptionTag extends ControlTagSupport
 
 		if (!this.getAttributeMap().containsKey("selected"))
 		{
-			HttpActionRequest request =
-				HttpActionRequestFactory.getInstance().getRequest(
-					(HttpServletRequest)pageContext.getRequest());
-			ConversionMap param = ConversionMap.valueOf(request.getParameterMap());
+			ConversionMap param = ConversionMap.valueOf(this.getParameterMap());
 			if (!param.isNull(parent.getName()))
 			{
 				if (param.isArray(parent.getName()))
