@@ -30,13 +30,10 @@ package jp.morpho.webapp.servlet.jsp.tagext.html;
 
 import java.io.IOException;
 
-import javax.servlet.http.HttpServletRequest;
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.JspWriter;
 
 import jp.morpho.util.ConversionMap;
-import jp.morpho.webapp.servlet.http.HttpActionRequest;
-import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;
 import jp.morpho.webapp.servlet.jsp.tagext.TagManager;
 import jp.morpho.webapp.servlet.jsp.tagext.TagTemplate;
 
@@ -370,10 +367,7 @@ public class TextareaTag
 		//^O{̂Ȃꍇ
 		if (!isBodyExists())
 		{
-			HttpActionRequest request =
-				HttpActionRequestFactory.getInstance().getRequest(
-					(HttpServletRequest)pageContext.getRequest());
-			ConversionMap param = ConversionMap.valueOf(request.getParameterMap());
+			ConversionMap param = ConversionMap.valueOf(this.getParameterMap());
 			if (param.containsKey(this.getName()))
 			{
 				HtmlEncoder encoder = this.getTagManager().getHtmlEncoder();
